@@ -1180,7 +1180,6 @@
             "ui-unsubscribe-from-changes";
         MessageType["UI_CHANGE_SETTINGS"] = "ui-change-settings";
         MessageType["UI_SET_THEME"] = "ui-set-theme";
-        MessageType["UI_SET_SHORTCUT"] = "ui-set-shortcut";
         MessageType["UI_TOGGLE_ACTIVE_TAB"] = "ui-toggle-active-tab";
         MessageType["UI_MARK_NEWS_AS_READ"] = "ui-mark-news-as-read";
         MessageType["UI_MARK_NEWS_AS_DISPLAYED"] = "ui-mark-news-as-displayed";
@@ -1282,7 +1281,14 @@
             return false;
         }
         const el = document.createElement("div");
-        el.setAttribute("style", "color-scheme: dark");
+        if (typeof el.style.colorScheme === "string") {
+            return true;
+        }
+        try {
+            el.setAttribute("style", "color-scheme: dark");
+        } catch (e) {
+            return false;
+        }
         return el.style && el.style.colorScheme === "dark";
     })();
 
@@ -2581,11 +2587,8 @@
                 });
             }
         }
-        setShortcut(command, shortcut) {
-            chrome.runtime.sendMessage({
-                type: MessageType.UI_SET_SHORTCUT,
-                data: {command, shortcut}
-            });
+        async setShortcut(command, shortcut) {
+            return null;
         }
         changeSettings(settings) {
             chrome.runtime.sendMessage({
